#
# spec file for package jo
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           jo
Version:        1.9
Release:        1.8
Summary:        JSON output from a shell
License:        GPL-2.0-or-later AND MIT
Group:          Productivity/Text/Utilities
URL:            https://github.com/jpmens/jo/
#Git-Clone:     https://github.com/jpmens/jo.git
Source:         https://github.com/jpmens/%{name}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  pkgconfig

%description
This is jo, a small utility to create JSON objects

%package bash-completion
Summary:        Bash Completion for %{name}
Group:          Productivity/Text/Utilities
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description bash-completion
Bash completion script for %{name}.

%package zsh-completion
Summary:        ZSH completion for %{name}
Group:          Productivity/Text/Utilities
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description zsh-completion
zsh shell completions for %{name}.

%prep
%setup -q

%build
autoreconf -fiv
export bashcompdir=%{_datadir}/bash-completion/completions/
%configure
%make_build

%install
%make_install
install -d %{buildroot}/%{_sysconfdir}/zsh_completion.d
mv %{buildroot}%{_datadir}/zsh/site-functions/_jo %{buildroot}%{_sysconfdir}/zsh_completion.d/%{name}

%check
%make_build check

%files
%license COPYING
%doc README ChangeLog AUTHORS
%{_bindir}/jo
%{_mandir}/man1/jo.1%{?ext_man}

%files bash-completion
%{_datadir}/bash-completion/completions/%{name}.bash

%files zsh-completion
%dir %{_sysconfdir}/zsh_completion.d
%config %{_sysconfdir}/zsh_completion.d/%{name}

%changelog
* Sat Dec  3 2022 Dirk Müller <dmueller@suse.com>
- update to 1.9:
  * FIX: fix reading of long lines from stdin (mk 2) (#195)
  * FIX: add missing test files (#196)
  * FIX: fix reading of long lines from stdin (mk 2) (#195)
* Sat Oct 29 2022 Martin Hauke <mardnh@gmx.de>
- Update to versino 1.7
  * FIX: fix reading of long lines from stdin and refactor
    slurp_file() in the process.
  * NEW: Add option -o outfile for when not run from a shell and
    redirect '>' is not an option.
* Wed Jan  5 2022 Martin Hauke <mardnh@gmx.de>
- Update to versino 1.6
  * FIX: repair tests broken by AUTHORS change
  * FIX: repair make distcheck by removing copied _jo zsh functions
* Tue Jan  4 2022 Martin Hauke <mardnh@gmx.de>
- Udpate to version 1.5
  * NEW: replace asserts with human errors
  * NEW: zsh completion
  * FIX: several cleanups
  * NEW: Meson build
  * NEW: option to deduplicate keys
  * NEW: Filter functionality
  * FIX: file embedding
  * FIX: add missing tests to Makefile.am
* Tue May 18 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Do not BuildRequire pandoc: it's not available on all
  architectures.
* Mon Jul 20 2020 Martin Hauke <mardnh@gmx.de>
- Update to versrion 1.4
  * FIX: Coercion flag logic now permits getopt(3) double-dash
  * FIX: Documentation clarifies special characters
  * FIX: Jo builds on snap builds
  * FIX: Jo builds on systems with slightly older pkg-config
* Mon Mar  9 2020 Martin Hauke <mardnh@gmx.de>
- Supplement against bash-completion, not bash
* Wed Nov  6 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.3
  * FIX: Escaped @ ("\@") is treated as "@"
  * NEW: Support reading JSON array elements
  * UPD: Add home and removable-media interfaces to snap
  * FIX: fix unlikely crash after malloc fail when base64 encoding.
  * NEW: Support reading nested data from pipes
- Add new subpackage for bash-completion
* Sun Mar  3 2019 Martin Hauke <mardnh@gmx.de>
- Run spec-cleaner
- Fix Source URL
- Run testsuite as part of %%check
- Update to version 1.2
  * UPD: add examples of empty arrays/objects to manual
  * NEW: support -e to ignore empty stdin
  * NEW: object-path support
- Update to version 1.1
  * NEW: type coercion
  * FIX: quotes in quotes and double quotes at begin of string
  * FIX: catch null value in assignmen
  * NEW: support for key:=file.json for reading object values
    from a file
  * FIX: "null" is now handled like we handle "true" and "false";
    disable with -B
  * NEW: more tests in the test suite
- Update to version 1.0
  * NEW: read JSON element values from files
  * FIX: usage diagnostic
- Update to version 0.9
  * UPD: revert support for $JO_PRETTY et. al; it was a bad idea
- Update to version 0.8
  * UPD: new test suite
  * NEW: support for nested elements
  * NEW: if $JO_PRETTY is set, jo will always pretty-print
  * NEW: Define $JO_SPACER to any desired number of spaces or
    tabs for pretty-printing
- Update to version 0.7
  * NEW: strings "true"/"false" now default to booleans; avoid with -B
  * FIX: test.sh get quotes to prevent failures with pdksh
  * FIX: pretty-print Version if requested
- Update to version 0.6
  - NEW: JSONy version with -V
* Tue Mar  8 2016 mrueckert@suse.de
- update to 0.5
  - proper fix for our fileno patch
- drop jo-0.4_make_build.patch
* Tue Mar  8 2016 mrueckert@suse.de
- initial package
